'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/button.html
 */
var button = {
  PROPS: [{
    name: 'size',
    get: function get(domNode) {
      return domNode.getAttribute('size') || 'default';
    }
  }, {
    name: 'type',
    get: function get(domNode) {
      return domNode.getAttribute('type') || 'default';
    }
  }, {
    name: 'plain',
    get: function get(domNode) {
      return !!domNode.getAttribute('plain');
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return !!domNode.getAttribute('disabled');
    }
  }, {
    name: 'loading',
    get: function get(domNode) {
      return !!domNode.getAttribute('loading');
    }
  }, {
    name: 'formType',
    get: function get(domNode) {
      return domNode.getAttribute('form-type') || '';
    }
  }, {
    name: 'openType',
    get: function get(domNode) {
      return domNode.getAttribute('open-type') || '';
    }
  }, {
    name: 'hoverClass',
    get: function get(domNode) {
      return domNode.getAttribute('hover-class') || 'button-hover';
    }
  }, {
    name: 'hoverStopPropagation',
    get: function get(domNode) {
      return !!domNode.getAttribute('hover-stop-propagation');
    }
  }, {
    name: 'hoverStartTime',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('hover-start-time'), 10);
      return !isNaN(value) ? value : 20;
    }
  }, {
    name: 'hoverStayTime',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('hover-stay-time'), 10);
      return !isNaN(value) ? value : 70;
    }
  }, {
    name: 'lang',
    get: function get(domNode) {
      return domNode.getAttribute('lang') || 'en';
    }
  }, {
    name: 'sessionFrom',
    get: function get(domNode) {
      return domNode.getAttribute('session-from') || '';
    }
  }, {
    name: 'sendMessageTitle',
    get: function get(domNode) {
      return domNode.getAttribute('send-message-title') || '';
    }
  }, {
    name: 'sendMessagePath',
    get: function get(domNode) {
      return domNode.getAttribute('send-message-path') || '';
    }
  }, {
    name: 'sendMessageImg',
    get: function get(domNode) {
      return domNode.getAttribute('send-message-img') || '';
    }
  }, {
    name: 'appParameter',
    get: function get(domNode) {
      return domNode.getAttribute('app-parameter') || '';
    }
  }, {
    name: 'showMessageCard',
    get: function get(domNode) {
      return !!domNode.getAttribute('show-message-card');
    }
  }, {
    name: 'businessId',
    get: function get(domNode) {
      return domNode.getAttribute('business-id') || '';
    }
  }],
  handles: {
    onButtonGetUserInfo: function onButtonGetUserInfo(evt) {
      this.callSimpleEvent('getuserinfo', evt);
    },
    onButtonContact: function onButtonContact(evt) {
      this.callSimpleEvent('contact', evt);
    },
    onButtonGetPhoneNumber: function onButtonGetPhoneNumber(evt) {
      this.callSimpleEvent('getphonenumber', evt);
    },
    onButtonError: function onButtonError(evt) {
      this.callSimpleEvent('error', evt);
    },
    onButtonOpenSetting: function onButtonOpenSetting(evt) {
      this.callSimpleEvent('opensetting', evt);
    },
    onButtonLaunchApp: function onButtonLaunchApp(evt) {
      this.callSimpleEvent('launchapp', evt);
    }
  }
};

exports.default = button;
