'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/picker.html
 */
var picker = {
  PROPS: [{
    name: 'mode',
    get: function get(domNode) {
      return domNode.getAttribute('mode') || 'selector';
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return !!domNode.getAttribute('disabled');
    }
  }, {
    name: 'range',
    get: function get(domNode) {
      var value = domNode.getAttribute('range');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'rangeKey',
    get: function get(domNode) {
      return domNode.getAttribute('range-key') || '';
    }
  }, {
    name: 'value',
    get: function get(domNode) {
      var mode = domNode.getAttribute('mode') || 'selector';
      var value = domNode.getAttribute('value');

      if (mode === 'selector' || mode === 'multiSelector') {
        return +value || 0;
      } else if (mode === 'time') {
        return value || '';
      } else if (mode === 'date') {
        return value || '0';
      } else if (mode === 'region') {
        return value || [];
      }

      return value;
    }
  }, {
    name: 'start',
    get: function get(domNode) {
      return domNode.getAttribute('start') || '';
    }
  }, {
    name: 'end',
    get: function get(domNode) {
      return domNode.getAttribute('end') || '';
    }
  }, {
    name: 'fields',
    get: function get(domNode) {
      return domNode.getAttribute('fields') || 'day';
    }
  }, {
    name: 'customItem',
    get: function get(domNode) {
      return domNode.getAttribute('custom-item') || '';
    }
  }],
  handles: {
    onPickerChange: function onPickerChange(evt) {
      if (!this.domNode) return;
      this.domNode.$$setAttributeWithoutUpdate('value', evt.detail.value);
      this.callSimpleEvent('change', evt);
    },
    onPickerColumnChange: function onPickerColumnChange(evt) {
      this.callSimpleEvent('columnchange', evt);
    },
    onPickerCancel: function onPickerCancel(evt) {
      this.callSimpleEvent('cancel', evt);
    }
  }
};

exports.default = picker;
