'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/textarea.html
 */
var textarea = {
  PROPS: [{
    name: 'value',
    get: function get(domNode) {
      return domNode.value || '';
    }
  }, {
    name: 'placeholder',
    get: function get(domNode) {
      return domNode.placeholder;
    }
  }, {
    name: 'placeholderStyle',
    get: function get(domNode) {
      return domNode.getAttribute('placeholder-style') || '';
    }
  }, {
    name: 'placeholderClass',
    get: function get(domNode) {
      return domNode.getAttribute('placeholder-class') || 'input-placeholder';
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return domNode.disabled;
    }
  }, {
    name: 'maxlength',
    get: function get(domNode) {
      var value = parseInt(domNode.maxlength, 10);
      return !isNaN(value) ? value : 140;
    }
  }, {
    name: 'autoFocus',
    get: function get(domNode) {
      return !!domNode.getAttribute('autofocus');
    }
  }, {
    name: 'focus',
    get: function get(domNode) {
      return !!domNode.getAttribute('focus');
    }
  }, {
    name: 'autoHeight',
    get: function get(domNode) {
      return !!domNode.getAttribute('auto-height');
    }
  }, {
    name: 'fixed',
    get: function get(domNode) {
      return !!domNode.getAttribute('fixed');
    }
  }, {
    name: 'cursorSpacing',
    get: function get(domNode) {
      return +domNode.getAttribute('cursor-spacing') || 0;
    }
  }, {
    name: 'cursor',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('cursor'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'showConfirmBar',
    get: function get(domNode) {
      var value = domNode.getAttribute('show-confirm-bar');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'selectionStart',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('selection-start'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'selectionEnd',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('selection-end'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'adjustPosition',
    get: function get(domNode) {
      var value = domNode.getAttribute('adjust-position');
      return value !== undefined ? !!value : true;
    }
  }],
  handles: {
    onTextareaFocus: function onTextareaFocus(evt) {
      this.callSimpleEvent('focus', evt);
    },
    onTextareaBlur: function onTextareaBlur(evt) {
      if (!this.domNode) return;
      this.domNode.setAttribute('focus', false);
      this.callSimpleEvent('blur', evt);
    },
    onTextareaLineChange: function onTextareaLineChange(evt) {
      this.callSimpleEvent('linechange', evt);
    },
    onTextareaInput: function onTextareaInput(evt) {
      if (!this.domNode) return;
      this.domNode.value = evt.detail.value;
      this.callEvent('input', evt);
    },
    onTextareaConfirm: function onTextareaConfirm(evt) {
      this.callSimpleEvent('confirm', evt);
    },
    onTextareaKeyBoardHeightChange: function onTextareaKeyBoardHeightChange(evt) {
      this.callSimpleEvent('keyboardheightchange', evt);
    }
  }
};

exports.default = textarea;
