'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/slider.html
 */
var slider = {
  PROPS: [{
    name: 'min',
    get: function get(domNode) {
      return +domNode.getAttribute('min') || 0;
    }
  }, {
    name: 'max',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('max'), 10);
      return !isNaN(value) ? value : 100;
    }
  }, {
    name: 'step',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('step'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return !!domNode.getAttribute('disabled');
    }
  }, {
    name: 'value',
    get: function get(domNode) {
      return +domNode.getAttribute('value') || 0;
    }
  }, {
    name: 'color',
    get: function get(domNode) {
      return domNode.getAttribute('color') || '#e9e9e9';
    }
  }, {
    name: 'selectedColor',
    get: function get(domNode) {
      return domNode.getAttribute('selected-color') || '#1aad19';
    }
  }, {
    name: 'activeColor',
    get: function get(domNode) {
      return domNode.getAttribute('active-color') || '#1aad19';
    }
  }, {
    name: 'backgroundColor',
    get: function get(domNode) {
      return domNode.getAttribute('background-color') || '#e9e9e9';
    }
  }, {
    name: 'blockSize',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('block-size'), 10);
      return !isNaN(value) ? value : 28;
    }
  }, {
    name: 'blockColor',
    get: function get(domNode) {
      return domNode.getAttribute('block-color') || '#ffffff';
    }
  }, {
    name: 'showValue',
    get: function get(domNode) {
      return !!domNode.getAttribute('show-value');
    }
  }],
  handles: {
    onSliderChange: function onSliderChange(evt) {
      if (!this.domNode) return;
      this.domNode.$$setAttributeWithoutUpdate('value', evt.detail.value);
      this.callSimpleEvent('change', evt);
    },
    onSliderChanging: function onSliderChanging(evt) {
      this.callSimpleEvent('changing', evt);
    }
  }
};

exports.default = slider;
